@@ -3,6 +3,7 @@ source('test_functions.R')
 
 test.get.wpp.data(2008)
 test.get.wpp.data(2010)
+test.get.wpp.data(2012)
 test.existing.simulation()
 test.e0trajectories()
 test.get.parameter.traces()
@@ -11,7 +12,7 @@ test.get.parameter.traces()
 ## Time-expensive tests
 # test.DLcurve()
 # test.plot.density()
-# #test.plot.map()
+# test.plot.map()
 # test.estimate.mcmc()
 # test.estimate.mcmc(compression='xz')
 # test.estimate.mcmc.with.suppl.data()
